import React, { useState, useEffect } from 'react';
import { Checkbox } from 'antd';
import classnames from 'classnames';
import styles from './itemCard.less';
import { checkChildrenByCondition, checkIsGroup, getId } from '.';

const ListCardItem = props => {
  const { searchWord, item, valueList, updateValueList, ouid } = props;

  // id
  const id = getId(item);
  // 是否是地图组件
  const isMapWedgt = item.type === 'widgetUIPage';

  // 当前组件是否是分组id
  const isGroup = checkIsGroup(item);
  const [indeterminate, setIndeterminate] = useState(!isGroup);
  const [childrenKeys, setChildrenKeys] = useState([]);
  useEffect(() => {
    if (isGroup) {
      const keys = checkChildrenByCondition(item, c => getId(c), 'map').flat();
      setChildrenKeys(keys);
    } else {
      //
    }
  }, [item]);

  // 勾选事件处理
  const handleChecked = e => {
    const { checked: v } = e.target;
    if (isGroup) {
      const result = [...childrenKeys, id];
      updateValueList(v ? result : [], result);
    } else {
      updateValueList(v ? [id] : [], [id]);
    }
  };

  const renderChild = () =>
    item.children &&
    item.children.map((c, i) => (
      <ListCardItem
        item={c}
        itemid={i}
        key={`item${i}key`}
        updateValueList={updateValueList}
        valueList={valueList}
        ouid={ouid}
        searchWord={searchWord}
      />
    ));

  return (
    <>
      <div
        className={classnames({
          [styles.divBox]: isGroup,
          [styles.divSingle]: !isGroup,
        })}
      >
        <div className={styles.topCheckbox}>
          <Checkbox
            indeterminate={isGroup ? indeterminate : false}
            checked={valueList.includes(id)}
            onChange={handleChecked}
          >
            {isMapWedgt ? (
              <div
                style={{ display: 'inline-block' }}
                ref={r => {
                  if (r) r.innerHTML = item.text;
                }}
              />
            ) : (
              <span
                className={classnames({
                  [styles.boldLabel]: isGroup,
                  [styles.isSearch]:
                    searchWord && item.text.includes(searchWord),
                })}
              >
                {item.text}
              </span>
            )}
          </Checkbox>
        </div>
        <div style={{ width: '100%' }} className={styles.checkdiv}>
          {renderChild()}
        </div>
      </div>
    </>
  );
};

export default ListCardItem;
