import React, { useState, useEffect, useCallback, useRef } from 'react';
import { Spin, Button, Empty } from 'antd';
import _ from 'lodash';
import ListCardItem from './ItemCard';
import { get, post } from '@/services';
import styles from './ItemCard.less';

const tip = 'loading...';

export const getId = item =>
  item.userID || item.roleID || item.stationID || item.id;
export const checkIsGroup = node =>
  ['widgetGroup'].includes(node?.type || node);
export const checkChildrenByCondition = (item, fn, tag = 'every') => {
  if (!checkIsGroup(item)) {
    return fn(item);
  }
  return item.children[tag](t => checkChildrenByCondition(t, fn, tag));
};

const ListCard = props => {
  const { ouid, searchWord, onCommit = () => {}, itemObj } = props;
  const [valueList, setValueList] = useState([]);
  const [dataList, setdataList] = useState([]);
  const [loading, setLoading] = useState(true);
  const [mapObj, setMapObj] = useState({});

  const updateValueList = (checkedKeys, childrenKeys) => {
    console.time('updateValueList:');
    const removekeys = _.difference(childrenKeys, checkedKeys);
    let result = _.uniq(_.union(checkedKeys, valueList));
    _.remove(result, v => removekeys.includes(v));
    setValueList(result);
    console.timeEnd('updateValueList:');
  };

  useEffect(() => {
    setLoading(true);
    const defaultConfig = {
      optionsList: [],
      title: '默认组',
      id: '',
    };
    // /Cityinterface/rest/services/OMS.svc/P_GetUserByStation
    //
    //  /Cityinterface/rest/services/OMS.svc/U_GetUserListForBatchOper
    get('/Cityinterface/rest/services/OMS.svc/W4_GetMenuByRoleWithLevel', {
      // OUID:ouid||'',
      // stationID: ouid || '',
      roleID: itemObj.roleID,
      subSystemValue: itemObj.subSystemValue,
      subSystemName: itemObj.subSystemValue,
      _version: 9999,
      _dc: new Date().getTime(),
    })
      .then(res => {
        const list = [];
        // eslint-disable-next-line no-unused-expressions
        res.success &&
          res.root.forEach(item => {
            list.push({ ...defaultConfig, ...item });
          });
        setdataList(list);
        setValueList(
          list
            .map(l =>
              checkChildrenByCondition(
                l,
                it => (it.isChecked ? [getId(it)] : []),
                'map',
              ).flat(Infinity),
            )
            .flat(Infinity)
            .filter(Boolean),
        );
        setLoading(false);
      })
      .catch(err => {
        console.error(err);
        setLoading(false);
      });
  }, [ouid]);
  return (
    <div>
      {loading ? (
        <Spin
          size="large"
          spinning={loading}
          tip={tip}
          style={{
            position: 'absolute',
            top: '30%',
            left: '0',
            right: '0',
            bottom: '0',
          }}
        />
      ) : (
        <>
          {dataList.some(d => d.type === 'widgetUIPage') && (
            <ListCardItem
              item={{
                type: 'widgetGroup',
                searchWord,
                children: dataList.filter(d => d.type === 'widgetUIPage'),
                text: '地图组件',
                itemid: '9999',
              }}
              ouid={ouid}
              updateValueList={updateValueList}
              valueList={valueList}
              searchWord={searchWord}
            />
          )}
          {dataList &&
            dataList.length > 0 &&
            dataList
              .filter(d => d.type === 'widgetGroup')
              .map((item, index) => (
                <ListCardItem
                  item={item}
                  ouid={ouid}
                  updateValueList={updateValueList}
                  valueList={valueList}
                  key={`item${index}key`}
                  searchWord={searchWord}
                  {...props}
                />
              ))}
        </>
      )}
      {true && !loading && dataList && (
        <div className={styles.btnBox}>
          <Button type="primary" onClick={() => onCommit(valueList)}>
            提交
          </Button>
        </div>
      )}
    </div>
  );
};

export default ListCard;
