import React, { useState, useEffect } from 'react';
import {
  Row,
  Col,
  Tree,
  Card,
  Input,
  Spin,
  notification,
  Button,
  Space,
} from 'antd';
import PageContainer from '@/components/BasePageContainer';
import {
  setMenuToRole,
  getRoleGroupList,
} from '@/services/userCenter/roleManage/api';
import ListCard from '@/components/CheckGroup';
// import ListCard from '@/pages/orgnazation/ListCard';
import qs from 'qs';
import styles from '@/pages/userCenter/roleManage/RoleManage.less';
import AddModal from './AddModal';
import DelModal from './DelModal';
import EditModal from './EditModal';
import EditGroup from './EditGroup';
const { Search } = Input;
const placeholder = '请输入功能名称';
const SiteManage = () => {
  const [treeData, setTreeData] = useState([]);
  const [searchWord, setSearchWord] = useState('');
  const [roleID, setRoleID] = useState(''); // 角色ID
  const [saveTreeId, setSaveTreeId] = useState(''); // 保存点击回调的ird
  const [modalVisible, setModalVisible] = useState(false); // 新增弹窗
  const [flag, setFlag] = useState(1);
  const [itemObj, setItemObj] = useState({}); // 选择的角色item
  const [delVisible, setDelVisible] = useState(false); // 删除弹窗
  const [editVisible, setEditVisible] = useState(false); // 修改弹窗
  const [subList, setSubList] = useState([]); // 选中的数组
  const [spinLoading, setSpinLoading] = useState(false);
  const [currentSelectId, setCurrentSelectId] = useState([]); // 选中的树节点
  const [groupVisible, setGroupVisible] = useState(false); // 分组编辑弹窗
  // 点击树的回调
  const handleTreeSelect = (e, treenode) => {
    const { node } = treenode;
    setItemObj(node);
    console.log(e, node, 'node');
    const { roleID: id } = node;
    // setCurrentSelectId(e);
    if (e[0]) {
      setCurrentSelectId(e);
      if (id) {
        setSaveTreeId(id);
        setRoleID(id);
      } else {
        setRoleID(saveTreeId);
      }
    } else {
    }
  };
  useEffect(() => {
    setSpinLoading(true);
    getRoleGroupList({ userID: 1 }).then(res => {
      console.log(res, 'res');
      setSpinLoading(false);
      if (res.code === 0) {
        const { roleList } = res.data;
        let arr = transTree(roleList);
        setTreeData(arr);
      }
    });
  }, [flag]);
  const handleAdd = e => {
    setModalVisible(true);
  };
  // 角色删除
  const handleDel = e => {
    setDelVisible(true);
  };
  // 编辑角色
  const handleEdit = e => {
    setEditVisible(true);
  };
  // 分组编辑
  const groupEdit = () => {
    setGroupVisible(true);
  };
  // 树形数据转换;
  const transTree = val => {
    let arr = val;
    let arr2 = arr.map(item => {
      if (item.child && item.child.length > 0) {
        item.child.forEach(itemC => {
          item.roleList.unshift(itemC);
        });
      }
      return item;
    });
    let arr3 = arr2.map(item => {
      item.title = item.visibleTitle || '';
      item.key = item.visibleValue || '';
      if (item.roleList && item.roleList.length > 0) {
        item.roleList.map(itemRole => {
          if (itemRole.roleList) {
            itemRole.title = itemRole.visibleTitle || '';
            itemRole.key =
              itemRole.visibleTitle + Math.floor(Math.random() * 100 + 1) || '';
            itemRole.groupflag = itemRole.visibleTitle;
            itemRole.roleList.map(i => {
              i.title = i.roleName;
              i.key = i.roleID;
              i.subSystemValue = item.visibleValue;
              i.group = itemRole.visibleTitle;
            });
            itemRole.children = itemRole.roleList;
          } else {
            itemRole.title = itemRole.roleName;
            itemRole.key = itemRole.roleID;
            itemRole.subSystemValue = item.visibleValue;
          }
          return itemRole;
        });
      }
      item.children = item.roleList;
      return item;
    });
    return arr3;
  };
  // 获取搜索框的值
  const handleSearch = value => {
    setSearchWord(value);
  };
  const handleChange = e => {
    const { value } = e.target;
    setSearchWord(value);
  };
  // 确认回调
  const confirmModal = e => {
    setModalVisible(false);
    setFlag(flag + 1);
    setItemObj('');
  };
  // 删除弹窗回调
  const delModal = () => {
    setDelVisible(false);
    setFlag(flag + 1);
    setItemObj('');
  };
  // 编辑弹窗回调
  const editModal = () => {
    setEditVisible(false);
    setFlag(flag + 1);
    setItemObj('');
  };
  // 分组编辑回调
  const groupModal = () => {
    setGroupVisible(false);
    setFlag(flag + 1);
    setItemObj('');
  };
  const valueCallback = valueObj => {
    setSubList(valueObj);
  };
  const handleCommit = rusults => {
    console.log(rusults);
    setMenuToRole(
      qs.stringify({
        roleID,
        menuNameList: String(rusults.flat()),
      }),
      {
        headers: {
          'content-type': 'application/x-www-form-urlencggoded;charset=UTF-8',
        },
      },
    )
      .then(res => {
        if (res.success) {
          notification.success({
            message: '提示',
            duration: 3,
            description: '设置成功',
          });
        } else {
          notification.error({
            message: '提示',
            duration: 15,
            description: res.message,
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };
  return (
    <PageContainer>
      {/* <GridContent> */}
      <Row gutter={12}>
        <Col lg={6}>
          <Card className={styles.cardBox}>
            <Spin
              tip="loading...."
              spinning={spinLoading}
              style={{ margin: '20px auto ', display: 'block' }}
            >
              {treeData && treeData.length > 0 && (
                <Tree
                  showLine={{ showLeafIcon: false }}
                  showIcon
                  onSelect={handleTreeSelect}
                  treeData={treeData}
                  // selectedKeys={currentSelectId}
                  blockNode
                  defaultExpandAll
                  // defaultExpandedKeys={currentSelectId}
                  autoExpandParent
                  expandedKeys={currentSelectId}
                />
              )}
            </Spin>
            <AddModal
              visible={modalVisible}
              onCancel={() => setModalVisible(false)}
              itemObj={itemObj}
              confirmModal={confirmModal}
            />
            <DelModal
              visible={delVisible}
              itemObj={itemObj}
              onCancel={() => setDelVisible(false)}
              confirmModal={delModal}
            />
            <EditModal
              visible={editVisible}
              itemObj={itemObj}
              onCancel={() => setEditVisible(false)}
              confirmModal={editModal}
            />
            <EditGroup
              visible={groupVisible}
              itemObj={itemObj}
              onCancel={() => setGroupVisible(false)}
              confirmModal={groupModal}
            />
          </Card>
        </Col>
        <Col lg={18}>
          <Card style={{ marginBottom: '10px' }}>
            <Row align="middle">
              <Col span={1}>搜索</Col>
              <Col span={8}>
                <Search
                  allowClear
                  placeholder={placeholder}
                  onSearch={handleSearch}
                  onChange={handleChange}
                  enterButton
                />
              </Col>
              <Col span={3} />
              <Col span={8}>
                <Space size="large">
                  <Button
                    type="primary"
                    onClick={() => {
                      handleAdd();
                    }}
                  >
                    新增角色
                  </Button>
                  <Button
                    type="primary"
                    disabled={!itemObj.roleID}
                    onClick={() => {
                      handleEdit();
                    }}
                  >
                    编辑角色
                  </Button>
                  <Button
                    danger
                    onClick={() => {
                      handleDel();
                    }}
                    disabled={!itemObj.roleID}
                  >
                    删除角色
                  </Button>
                  <Button
                    type="primary"
                    onClick={() => {
                      groupEdit();
                    }}
                    disabled={!itemObj.groupflag}
                  >
                    编辑分组
                  </Button>
                </Space>
              </Col>
            </Row>
          </Card>
          <Card className={styles.cardBoxR}>
            {roleID && (
              <ListCard
                ouid={roleID}
                itemObj={itemObj}
                searchWord={searchWord}
                onCommit={handleCommit}
              />
            )}
          </Card>
        </Col>
      </Row>
      {/* </GridContent> */}
    </PageContainer>
  );
};

export default SiteManage;
